      PROGRAM CGAP
C                 CHANNEL GEOMETRY ANALYSIS PROGRAM                    C
C                                                                      C
C Last modified July 19, 1993 -- RSR
C modified July 1, 1993 -- RSR
C modified May 27, 1993 -- RSR
C modified April 9, 1993 -- RSR
C modified March 10, 1993 -- RSR
C modified December 11, 1992
C modified July 27, 1992 -- RSR
C                                                                      C
C THE FUNCTION OF THIS FORTRAN 77 PROGRAM IS TO PROCESS, DISPLAY,      C
C AND/OR FORMAT CHANNEL CROSS-SECTION DATA FOR INPUT TO SPECIFIC       C
C MATHEMATICAL FLOW MODELS. NO ALTERNATE USE OF THE PROGRAM IS         C
C EXPRESSED, IMPLIED, OR INTENDED.                                     C
C                                                                      C
C                             SUBROUTINES                              C
C                                                                      C
C 1) SOURCE  - CALAWP,CHARAC,DRAXIS,IDINFO,PERPLT,PLOTER,SCALER,XLOC,  C
C              HIDPT,PROFIL,SUBDIV,ERRPRT,XTRPBN,LSTOPT                C
C 2) FORTRAN - ABS,COS,MOD,SQRT                                        C
C 3) CALCOMP - AXIS,LINE,PLOT,PLOTS,SCALE,SYMBOL,FACTOR                C
C 4) SYSTEM  - SYSDATE                                                 C
C                                                                      C
C                              INPUT DATA                              C
C                                                                      C
C 1) IDENTITY RECORD (1 PER EXECUTION, WITH ALL FIELDS CENTERED IN     C
C                   ALLOTTED SPACE)                                    C
C         7-28 RIVER OR ESTUARY NAME                                   C
C        30-51 STATION NAMES IDENTIFYING REACH EXTENT                  C
C        53-57 RANGE OF CROSS SECTION NUMBERS INCLUDED IN THE REACH    C
C 2) OBJECT TIME FORMAT RECORD (1 PER EXECUTION; IF THIS RECORD IS     C
C                       BLANK, A DEFAULT FORMAT WILL BE USED AS        C
C                       STATED UNDER SECTION 5, ENTITLED "DATA INPUT") C
C         1-60 FORTRAN FORMAT STATEMENT DEFINING FORMAT OF CD RECORD   C
C        63-64 FORTRAN UNIT NUMBER OF PRINTER OUTPUT (DEFAULT=66)      C
C        65-66 FORTRAN UNIT NUMBER OF PUNCHED OUTPUT (DEFAULT=7)       C
C        67-68 FORTRAN UNIT NUMBER OF DIGITAL PLOTER OUTPUT (DEF=9)    C
C        69-70 FORTRAN UNIT NUMBER OF STANDARD FORMAT FILE (DEFAULT=67)C
C        71-72 FORTRAN UNIT NUMBER OF SUBDIVISION OUTPUT (DEFAULT=16)  C
C           76 E431 DATA FLAG (SET TO 1 IF E431-FORMATTED DATA INPUT)  C
C           78 DATA SET REFERENCE NUMBER FLAG FOR CROSS-SECTION DATA   C
C              (DEFAULT IS CARD READER, INSTREAM INPUT)                C
C              A) A DATA SET REFERENCE VALUE OF 1 INDICATES THAT THE   C
C                 CD IS SEQUENTIALLY ARRANGED AND RESIDES ON DISK.     C
C                 OTHERWISE ALL DATA WILL BE READ AND STORED ON A      C
C                 STANDARD FORMAT FILE (UNIT 67), SO THAT MORE THAN    C
C                 ONE OPTION CAN BE REQUESTED IN A SINGLE EXECUTION.   C
C              B) IF USING OPTION 9, THE DATA SET 67 (TEMPFILE) MUST   C
C                 BE MADE PERMANENT.                                   C
C           80 DATA SET REFERENCE NUMBER FLAG FOR READING PCS RECORDS  C
C              WITH CD RECORDS (DEFAULT IS NOT FOUND WITH CD RECORDS)  C
C 3) PARAMETER RECORD (1 PER CROSS-SECTION)                            C
C         1- 2 CROSS SECTION NUMBER                                    C
C         3- 4 UNITS OF MEASURE FOR CROSS SECTION (EN,ME)              C
C         5    NUMBER OF COMMENT RECORDS FOLLOWING                     C
C         6-12 MINIMUM STAGE TO BE COMPUTED: ADJUSTED TO DESIRED DATUM C
C        13-19 MAXIMUM STAGE TO BE COMPUTED: ADJUSTED TO DESIRED DATUM C
C        20-26 SUCCESSIVE INCREMENTS OF STAGE TO BE COMPUTED           C
C              (DEFAULT = 1.0)                                         C
C        27-29 DEGREE VARIATION FROM THALWEG                           C
C        30-35 DISTANCE FROM REFERENCE POINT OR SUBREACH LENGTH        C
C              A) IF DISTANCES INPUT ARE ACTUAL DISTANCES BETWEEN      C
C                 CROSS-SECTIONS, THEN FOR CROSS-SECTION #1 THIS FIELD C
C                 MUST CONTAIN 0.                                      C
C              B) IF USING A REFERENCE POINT, DO NOT USE SECTION #1.   C
C                 (I. E., THE DISTANCE FIELD OF CROSS-SECTION #1 = 0)  C
C        37-38 FIRST MEAN GROUP: MUST BE AN INTEGER FROM 0 TO 99.      C
C        39-40 SECOND MEAN GROUP: MUST BE AN INTEGER FROM 0 TO 99.     C
C              IF THE COMPUTATION OF MEANS IS REQUESTED FOR OPTIONS    C
C              6 OR 8, THEN EACH CROSS-SECTION MAY BE INCLUDED IN AT   C
C              MOST TWO COMPUTED MEANS.  THE SETTING OF THE MEAN GROUP C
C              INVOLVE WHICH CROSS-SECTIONS.  IF BOTH MEAN GROUPS      C
C              EQUAL 0 FOR ALL CROSS-SECTIONS INPUT, THE THE OUTPUT OF C
C              THE MEANS REQUEST WILL BE 1 GEOMETRY TABLE FOR EACH     C
C              INPUT CROSS SECTION.  UP TO 100 SEPARATE MEAN GROUPS    C
C              MAY BE SPECIFIED.                                       C
C        41-48 DACORR - REFERENCE LEVEL FOR STAGE VALUES RELATIVE TO   C
C              THE COMMON DATUM, I.E. MEAN SEA LEVEL                   C
C        50-55 STAGING - SCALE INCREMENT FOR CROSS SECTION AND STAGE-  C
C              DEPENDENT RELATIONSHIP PLOTS.                           C
C        57-62 DISTANCE INCREMENT - SCALING FOR CROSS SECTION PLOTS.   C
C         64   NSUBS - NUMBER OF Y VALUES INPUT FOR SUBDIVISIONS.      C
C        65-70 AREA INCREMENT - SCALING FOR PLOTS OF STAGE-DEPENDENT   C
C              CROSS-SECTIONAL AREA.                                   C
C        71-76 WIDTH INCREMENT - SCALING FOR PLOTS OF STAGE-DEPENDENT  C
C              CHANNEL WIDTH.                                          C
C 4) COMMENT RECORDS (5 OR LESS PER CROSS-SECTION)                     C
C         1-80 LITERAL INFORMATION PERTAINING TO CROSS SECTION.        C
C 5) SUBDIVISION RECORD (1 PER CROSS SECTION IF SUBDIVISIONS DESIRED)  C
C         3-50 DISTANCES AT WHICH THE CROSS SECTION IS SUBDIVIDED.     C
C 6) COORDINATE DATA (100 OR LESS PER CROSS-SECTION, FOLLOWED BY ONE   C
C                BLANK RECORD)  STORE ON DISK AS A SEQUENTIAL DATA SET C
C                UNDER                                                 C
C    DDNAME FT10F001                                                   C
C    THE DEFAULT FORMAT IS AS FOLLOWS:                                 C
C         1- 2 CROSS SECTION NUMBER (NOT READ BY CGAP)                 C
C        15-22 DISTANCE FROM  REFERENCE POINT                          C
C        26-33 ELEVATION AT POINT                                      C
C        39-40 DATA POINT NUMBER                                       C
C 7) PROGRAM CONTROL RECORDS                                           C
C         1- 2 UNITS OF MEASURE OF OUTPUT RESULTS.                     C
C         3- 4 OUTPUT OPTION (DEFAULT = 5)                             C
C              NOTE: THE PLOTTING SUBROUTINES FOR THE CALCOMP PLOTER   C
C              ARE COMPATABLE WITH THE ZETA PLOTER.                    C
C              1 - STAGE-AREA PLOT USING LINE PRINTER                  C
C              2 - STAGE-WIDTH PLOT USING LINE PRINTER                 C
C              3 - STAGE CURVE PLOTS USING LINE PRINTER                C
C              4 - CROSS SECTION PLOTS USING LINE PRINTER              C
C              5 - TABULAR OUTPUT                                      C
C              6 - PUNCHED OUTPUT (AREA AND WIDTH VS. STAGE)           C
C              7 - 3-DIMENSIONAL PLOT USING CALCOMP PLOTTER            C
C              8 - PUNCHED OUTPUT(WETTED PER. AND HYDRAULIC RAD.)      C
C              9 - STORE DATA ON DISK AS SEQUENTIAL DATA SET UNDER     C
C                  DDNAME FT67F001                                     C
C              10 - STRAIGHT DATA SET LISTING WITH HEADINGS            C
C              11 - STAGE-AREA PLOT USING CALCOMP PLOTTER              C
C              12 - STAGE-WIDTH PLOT USING CALCOMP PLOTTER             C
C              13 - STAGE CURVES PLOTTED USING CALCOMP PLOTTER         C
C              14 - CROSS SECTIONS PLOTTED USING CALCOMP PLOTTER       C
C              15 - STAGE PROFILE PLOTS USING LINE PRINTER             C
C              16 - TABULAR OUTPUT (AREA AND WIDTH) FOR SUBDIVISIONS   C
C         5- 6 SIZE OF PLOT FOR CALCOMP PLOTTER--FOR OPTIONS 11-14     C
C         ONLY (DEFAULT = 6)                                           C
C              THIS FIELD MUST EQUAL 4, 6, 8, OR 10. IT WILL REPRESENT C
C              THE SIZE OF THE Y-AXIS OF THE PLOT, WITH THE X-AXIS 5/4 C
C              AS LARGE.                                               C
C         7- 9 DEGREE OF ROTATION OF THALWEG FROM Y-AXIS FOR 3D PLOT-- C
C              FOR OPTION 7 ONLY (DEFAULT = 75.0)                      C
C        13-15 NUMBER OF PARAMETER RECORDS TO BE ALTERED FOR THIS      C
C              OPTION PARAMETER ALTERATIONS ARE READ IN AFTER EACH     C
C              PROGRAM CONTROL RECORD                                  C
C        16-18 FLAG TO INDICATE THAT THE ALTERNATE OUTPUT FILE FORMAT  C
C              IS TO BE USED WITH OPTIONS 6 OR 8 (0=N,1=Y).            C
C        19-26 DAREF - ELEVATION TO BE ADDED TO CD ELEVATIONS OF ALL   C
C              CROSS SECTIONS.                                         C
C        27-28 CROSS SECTION NUMBER OF INITIAL CROSS SECTION FOR       C
C              STAGE PROFILE PLOTS--FOR OPTION 15 ONLY. (DEFAULT = 1)  C
C        29-30 NUMBER OF CONSECUTIVE CROSS-SECTIONS INCLUDED IN STAGE  C
C              PROFILE PLOTS--FOR OPTION 15 ONLY.  (BOTH MAXIMUM AND   C
C              DEFAULT = 50)                                           C
C        31-32 NUMBER OF STAGE VALUES PER PLOT--FOR OPTION 15 ONLY.    C
C              (SET EQUAL TO 1-5; DEFAULT = 4)                         C
C        33-52 REFERENCE NAME OF COMMON DATUM FOR OUTPUT LABELING.     C
C           53 FLAG TO PUT FULL GRID ON STAGE-DEPENDENT PLOTS 0=N,1=Y  C
C        54-58 SIZE OF LABELING OF ISOMETRIC PLOT (DEFAULT=0.15)       C
C                                                                      C
C VERSION 710802 PROGRAMMED BY R. W. SCHAFFRANEK                       C
C VERSION 750731 MODIFIED BY F. VAROSI                                 C
C VERSION 800715 MODIFIED BY R. PAUL                                   C
C VERSION 840801 MODIFIED BY D. BRYSON                                 C
C VERSION 850715 MODIFIED BY S. REGAN                                  C
C VERSION 860220 MODIFIED BY R. S. REGAN  DOCUMENT = USGS WRI 85-4335  C
C VERSION 870730 MODIFIED BY R. S. REGAN                               C
C VERSION 880601 MODIFIED BY R. S. REGAN                               C
C VERSION 890401 MODIFIED BY R. S. REGAN                               C
C                                                                      C
C COMPILATION RESTRICTION:  PROGRAM IS NOT COMPATIBLE WITH             C
C                           FORTRAN IV DO LOOP CONVENTIONS.            C
C                                                                      C
C                       RAYMOND W. SCHAFFRANEK                         C
C                       U. S. GEOLOGICAL SURVEY, WRD                   C
C                       NATIONAL CENTER - #430                         C
C                       RESTON, VA.  22092                             C
C                       (703) 648-5891                                 C
C                                                                      C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                      C
C                                                                      C
      INCLUDE 'cgdims.cmn'
      INCLUDE 'mngrps.cmn'
      INCLUDE 'prmalt.cmn'
      INCLUDE 'comdat.cmn'
      INCLUDE 'cgunit.cmn'
      INCLUDE 'comany.cmn'
      INCLUDE 'comsbd.cmn'
      INCLUDE 'comawp.cmn'
      INCLUDE 'comtdp.cmn'
      INCLUDE 'cgcctl.cmn'
      INCLUDE 'comax.cmn'
      INCLUDE 'comhid.cmn'
      INCLUDE 'errcmn.cmn'
      INTEGER irem, e431, i, j, k, l, kk, ierr, is, ione, iold, nxpos, 
     &        nset, prtgrd, limit, idref, altpch, izflg, izzflg, jsta, 
     &        lastl, ktrec, n, mean, mark, nn
      REAL ara, wid, dmy, amin, Z(MXPTS2), amax, dc, zi, delta, d1, d2, 
     &     d3, dz, savdlt, savmin, yscale, xscale, bass, ymin, zstage, 
     &     xp, yp, szmin, szmax, stage1, stg1, swtp, swid, mangsn, wtp,
     &     sara
      REAL fslope, hyrad, qq, shyrad
      CHARACTER*1 numb(10), charst(154), stanam(22), xsrang(5)
      CHARACTER*22 chrsta, lab(9)
      EQUIVALENCE (charst(1),chrsta)
      CHARACTER*8 sub1, blank8
      CHARACTER deffmt*26, form*60, versn*64, card*112
      CHARACTER*80 ident(MAXCOM)
      CHARACTER*20 ngvd
      INTEGER iy(MXPTS2), Iwide(MXCOMP), jwetp(MXCOMP), jwide(MXCOMP), 
     &        jarea(MXCOMP), Iarea(MXCOMP), iwlt(MXCOMP), iwplt(MXCOMP), 
     &        iart(MXCOMP), iwrt(MXCOMP), iwprt(MXCOMP), ialt(MXCOMP)
      REAL stagj(MXCOMP), yhrad(MXCOMP), Rwetp(MXCOMP), avedep(MXCOMP), 
     &     avdep(MXCOMP), ymide(MXCOMP)
      INTEGER Larea(MXCOMP,MAXS15), ipnt, ktxs, nplt, ldist(MAXS15), 
     &        lcnt
CC    INTEGER LWIDTH(MXCOMP,MAXS15)
      REAL Stage(MXCOMP), stemp, deltai, snvmax
      REAL Xhrad(MXCOMP), Xwide(MXCOMP)
      INTEGER Iwetp(MXCOMP)
      COMMON /BIGCMN/ Stage, Xhrad, Xwide, Rwetp, Larea, Iarea, Iwide, 
     &                Iwetp
      EQUIVALENCE (charst(45),stanam(1)), (charst(119),xsrang(1))
      EQUIVALENCE (H(1),Z(1))
      LOGICAL dflg, note, idck, iak, opt16, opt68, opt9, skpflg, flg, 
     &        yerr, xerr, subs, prtfg, mnsflg, le431, prtflg
      DATA numb/'0', '1', '2', '3', '4', '5', '6', '7', '8', '9'/, 
     &     opt68/.FALSE./
      DATA ngvd/'NGVD OF 1929        '/, opt16/.FALSE./, opt9/.FALSE./
      DATA charst/74*' ', 'R', 'E', 'A', 'C', 'H', 13*' ', 'C', 'R', 
     &     'O', 'S', 'S', ' ', 'S', 'E', 'C', 'T', 'I', 'O', 'N', 'S', 
     &     35*' ', '/', 2*' ', '/', 9*' '/
      DATA blank8/'        '/
      DATA dz/.1/, idref/0/
      iak = .FALSE.
      subs = .FALSE.
      ipnt = 1
      lastl = 1
      nxpos = 0
      altpch = 0
      stemp = 99999.0
      deltai = 1.0
      savdlt = 1.0
      Lblclr = 15
      card = 
     &    '$Id: cgap.f,v 3.5 1995/10/06 18:12:16 rsregan Exp rsregan $'
      versn = 
     &    '@(#)CGAP - A Computer Program for Analyzing Channel Geometry'
      versn = 
     &   '@(#)CGAP - USGS WRIR 85-4335, R.S. Regan and R.W. Schaffranek'
      versn = '@(#)CGAP - Contact: h2osoft@usgs.gov'
      versn = '@(#)CGAP - Version: 3.5x 1995/10/06'
C     this string (characters 1-24) is used for labeling printouts.
      versn = 'Version: '//card(15:29)
C
      lab(1) = '  STAGE-AREA PLOT OF  '
      lab(2) = '  STAGE-WIDTH PLOT OF '
      lab(3) = '   STAGE CURVES OF    '
      lab(4) = 'CROSS-SECTION PLOTS OF'
      lab(5) = '  TABULAR OUTPUT FOR  '
      lab(6) = 'PUNCHED CARD OUTPUT OF'
      lab(7) = 'THREE DIMENSIONAL PLOT'
      lab(8) = 'STAGE-PROFILE PLOTS OF'
      lab(9) = 'CROSS-SECTION DATA FOR'
      deffmt = '(T15,F8.1,T26,F8.2,T39,I2)'
C
C READ IDENTITY RECORD AND SET DATE IN HEADER PAGE
C
      CALL CIOFIL(versn(:24))
      READ (Irdr,'(6X,2(22A1,1X),5A1)',END=510) Ibcd, stanam, xsrang
      DO 10 i = 1, 22
        charst(i+22) = Ibcd(i)
   10 CONTINUE
C
C READ OBJECT TIME FORMAT RECORD AND DATA SET REFERENCE NUMBERS
      READ (Irdr,'(A60,2X,5I2,2X,3(1X,I1))',END=510,ERR=510) form, Iprt, 
     &      Ipun, Pltunt, Stndrd, Sbdunt, e431, Idev, Kdev
      IF (Iprt.EQ.0) Iprt = 66
      IF (Ipun.EQ.0) Ipun = 7
      IF (Pltunt.EQ.0) Pltunt = 9
      IF (Stndrd.EQ.0) Stndrd = 67
      IF (Sbdunt.EQ.0) Sbdunt = 16
      le431 = e431.EQ.1
      Pflag = .FALSE.
      IF (Iprt.EQ.6 .OR. Iprt.EQ.11 .OR. Stndrd.EQ.6 .OR. 
     &    Stndrd.EQ.11 .OR. Iprt.EQ.5 .OR. Ipun.EQ.6 .OR. 
     &    Ipun.EQ.11 .OR. Sbdunt.EQ.6 .OR. Sbdunt.EQ.11 .OR. 
     &    Pltunt.EQ.6 .OR. Pltunt.EQ.11 .OR. Ipun.EQ.5 .OR. Stndrd.EQ.5)
     &    THEN
        ierr = 36
        GOTO 520
      ENDIF
      j = 0
      DO 20 i = 1, 60
        IF (form(i:i).NE.' ') THEN
          j = 1
          GOTO 30
        ENDIF
   20 CONTINUE
   30 IF (j.EQ.0 .OR. le431) form = deffmt
C
C SYSDATE IS AN IBM SYSTEM SUBROUTINE THAT RETURNS
C INTEGER VALUES FOR THE YEAR, MONTH, AND DAY.
C YOU MAY CREATE AN EQUIVALENT SUBROUTINE USING THE PRIME TIMDAT ROUTINE
      CALL SYSDATE(k,kk,is)
C
      DO 40 i = 1, 3
        IF (i.EQ.2) k = kk
        IF (i.EQ.3) k = is
        j = k/10
        l = (i-1)*3
        charst(140+l) = numb(j+1)
        charst(141+l) = numb(k-j*10+1)
   40 CONTINUE
C
      IF (Idev.EQ.0) THEN
        Idev = Irdr
        Kdev = Irdr
      ELSEIF (Idev.EQ.1) THEN
        Idev = Ipcs
        IF (Kdev.EQ.0) THEN
          Kdev = Irdr
        ELSE
          Kdev = Ipcs
        ENDIF
      ELSE
        ierr = 1
        GOTO 520
      ENDIF
      CALL CIOFIL(versn(:24))
C
C CREATE STANDARD FORMAT FILE:  SORT DATA AND ELIMINATE DUPLICATIONS
C
      CALL STNDFL(le431,deffmt,form)
C
C     FINISHED READING INPUT DATA FOR EACH CROSS SECTION.
C
      Idev = Stndrd
C
C     READ PROGRAM CONTROL RECORD
C
      IF (Kdev.NE.Ipcs) BACKSPACE Irdr
      GOTO 80
C
   50 IF (.NOT.subs) THEN
        CALL ERRPRT(34)
        GOTO 80
      ENDIF
      skpflg = .FALSE.
      IF (nxpos.NE.0) skpflg = .TRUE.
      IF (Iflag.EQ.1 .AND. Iopt.EQ.7) THEN
        Iflag = 2
        GOTO 340
      ENDIF
C
      IF ((Iopt.EQ.6 .OR. Iopt.EQ.8 .OR. Iopt.EQ.17) .AND. altpch.EQ.0)
     &    CALL MEANOT(Iopt)
C
      IF (Iopt.EQ.15) THEN
        IF (Parm.EQ.0) THEN
          ierr = 35
          CALL ERRPRT(35)
          GOTO 80
        ENDIF
        IF (iak) THEN
          snvmax = stemp
        ELSE
          snvmax = Savmax
        ENDIF
C
C PREPARE STAGE PROFILES FOR PLOTTING (OUTPUT OPTION 15)
C
        j = IFIX((snvmax-Stage(ipnt))*deltai) + 1
        limit = FLOAT(j)/FLOAT(Nstage) + 0.9
        j = 1
        nplt = Nstage
        lcnt = ipnt
   60   IF (j.GT.limit) THEN
          IF (iak) Savmax = snvmax
          iak = .FALSE.
          IF (ABS(Stage(lcnt-1)-Savmax).GT.savdlt*.1) CALL ERRPRT(22)
        ELSE
          CALL PROFIL(Larea,Stage,ldist,lcnt,ipnt,Nstage,j,ktxs,Iprt,
     &                snvmax,deltai,0,nplt,limit)
          j = j + 1
          lcnt = lcnt + nplt
          ipnt = lcnt
          GOTO 60
        ENDIF
      ENDIF
C
      IF (Iopt.EQ.7 .OR. (Iopt.GT.10 .AND. Iopt.LT.15)) Pflag = .TRUE.
      IF (Iopt.LT.7 .OR. Iopt.EQ.15) WRITE (Iprt,9005)
   70 WRITE (Iprt,9040) Iopt
      IF (Iopt.EQ.6 .OR. Iopt.EQ.8 .OR. Iopt.EQ.17) opt68 = .TRUE.
   80 READ (Irdr,9165,END=530,ERR=510) Iopt, Leny, Thedeg, Npar, altpch, 
     &                                 Daref, nxpos, nset, Nstage, 
     &                                 Dtmnam, prtgrd, Siz3d
C
C READ PARAMETER ALTERATIONS, IF ANY
C
      IF (Npar.GT.MAXALT) THEN
        DO 90 i = 1, Npar
          READ (Irdr,9015,END=510)
   90   CONTINUE
        CALL ERRPRT(17)
        GOTO 80
      ENDIF
      DO 100 i = 1, Npar
        READ (Irdr,9015,ERR=510,END=510) Nxsec(i), Ncom, Tmin(i), 
     &        Tmax(i), Tinc(i), Ddeg(i), Kdsd(i), Kmn1(i), Kmn2(i), 
     &        Datm(i), Tzinc(i), Tdinc(i), Nsubs, Tainc(i), Twinc(i), j, 
     &        Tslope(i), Tmansn(i)
  100 CONTINUE
      IF (Iopt.EQ.0) Iopt = 5
      IF (Iopt.LT.0 .OR. Iopt.GT.17) THEN
        CALL ERRPRT(25)
        GOTO 80
      ENDIF
      IF (Iopt.EQ.9) THEN
        WRITE (Iprt,9175)
        opt9 = .TRUE.
        GOTO 70
      ENDIF
C
C    SET DEFAULTS
C
      IF (Leny.LT.4) Leny = 6
      IF (Leny.GT.12) Leny = 12
      IF (MOD(Leny,2).NE.0) Leny = Leny + 1
      Lenx = Leny + Leny/4
      IF (MOD(Lenx,5).NE.0 .AND. MOD(Lenx,2).NE.0) Lenx = Lenx + 1
      IF (Thedeg.LT.45.) Thedeg = 75.0
      IF (Dtmnam.EQ.'                    ') Dtmnam = ngvd
C
      REWIND Idev
C
C   CHOOSE, ACCORDING TO IOPT, THE ELEMENTS OF THE CHARST ARRAY FOR THE
C   IDINFO (HEADER PAGE) SUBROUTINE
      IF (Iopt.LT.10) THEN
        k = Iopt
      ELSEIF (Iopt.EQ.8 .OR. Iopt.EQ.17) THEN
        k = 6
      ELSEIF (Iopt.EQ.15) THEN
        k = 8
      ELSEIF (Iopt.EQ.16) THEN
        k = 5
      ELSEIF (Iopt.EQ.10) THEN
        k = 9
      ELSE
        k = Iopt - 10
      ENDIF
      chrsta = lab(k)
      irem = 7
      CALL IDINFO(charst,irem,2)
      WRITE (Iprt,9030) versn(:24)
      IF (Iopt.EQ.10) THEN
        WRITE (Iprt,9155)
        CALL LSTOPT(deffmt,ierr,*520,*510)
        GOTO 80
      ENDIF
      skpflg = .FALSE.
      IF (nxpos.NE.0) skpflg = .TRUE.
      IF (nset.EQ.0 .OR. nset.GT.MAXS68) nset = MAXS68
      IF (Iopt.EQ.15) THEN
        IF (nset.EQ.0) nset = MAXS15
        IF (nset.GT.MAXS15) THEN
          CALL ERRPRT(23)
          GOTO 80
        ENDIF
        IF (Nstage.EQ.0) Nstage = MXPSTG
      ENDIF
C
      mnsflg = (Iopt.EQ.6 .OR. Iopt.EQ.8 .OR. Iopt.EQ.17) .AND. 
     &         altpch.EQ.0
      IF (Iopt.EQ.16) opt16 = .TRUE.
      subs = .FALSE.
      Parm = 0
      ktxs = 0
      idref = 0
      ktrec = 0
      Iflag = 999
      Diff = 0.0
      stemp = 99999.0
      iak = .FALSE.
      note = .FALSE.
      idck = .FALSE.
      prtflg = (prtgrd.EQ.0)
C
C STORE PARAMETER ALTERATIONS FOR MEAN COMPUTATION
C
      IF (.NOT.mnsflg) GOTO 170
      Inxs = 0
      flg = .NOT.skpflg
  110 READ (Idev,9015,END=160,ERR=510) Nsta, Ncom, Zmin, Zmax, Deltaz, 
     &                                 Deg, Ndsd, Mn1, Mn2, Dacorr, 
     &                                 Zinc, Dinc, Nsubs, Ainc, Winc, 
     &                                 Many, fslope, mangsn
      DO 120 i = 1, Ncom
        READ (Idev,9005)
  120 CONTINUE
      IF (Nsubs.NE.0) READ (Idev,9005,ERR=510)
      IF (Nsta.EQ.nxpos) flg = .TRUE.
      IF (flg) Inxs = Inxs + 1
      IF (Inxs.LE.nset) THEN
        delta = Deltaz
        IF (delta.EQ.0.0) delta = 1.0
        IF (Inxs.GT.MXGRPS) THEN
          CALL ERRPRT(21)
          GOTO 80
        ENDIF
        DO 130 i = 1, Npar
          IF (Nsta.EQ.Nxsec(i)) THEN
            Mn1 = Kmn1(i)
            Mn2 = Kmn2(i)
            Zmin = Tmin(i)
            Zmax = Tmax(i)
            GOTO 140
          ENDIF
  130   CONTINUE
  140   Mnpr(1,Inxs) = Mn1
        Mnpr(2,Inxs) = Mn2
        Nxsect(Inxs) = Nsta
        dc = Dacorr + Daref
        Zmin = Zmin + Daref
        DO 150 i = 1, Many
          READ (Idev,deffmt,ERR=510) Y(i), zi
          Z(i) = zi + dc
  150   CONTINUE
        READ (Idev,deffmt)
        CALL CMINMX(Z,Many,Zzmin,Zzmax)
        CALL MINSTG(Z,Many,Zzmin,Zmin,Zmax,delta,Iopt,l,j,*80)
        Zmnn(Inxs) = Zmin
        Zzmnn(Inxs) = Zzmin
        GOTO 110
      ENDIF
  160 REWIND Idev
C VALIDATE INPUT MEAN PAIRS AND INITIALIZE MEAN ARRAYS AND DETERMIN ZMN & ZMX
      CALL MNGRPV(Inxs,*80)
C
C DETERMINE ABSOLUTE MINIMUM STAGE AND NUMBER OF CROSS SECTIONS INPUT
C FOR OUTPUT OPTION 7
  170 IF (Iopt.EQ.7 .OR. Iopt.EQ.14) THEN
        IF (Iopt.EQ.7) Iflag = 1
        CALL MINXS7(Iopt,Slow,Hgtmax,Distmn,Distmx,Inxs,nxpos,nset)
        Slow = Slow + Daref
        Hgtmax = Hgtmax + Daref
      ENDIF
C
C READ PARAMETER RECORD AND WRITE OUT HEADER PAGE
  180 kk = 0
  190 l = 1
      dflg = .FALSE.
      ktrec = ktrec + 1
      READ (Idev,9015,END=50,ERR=510) Nsta, Ncom, Zmin, Zmax, Deltaz, 
     &                                Deg, Ndsd, Mn1, Mn2, Dacorr, Zinc, 
     &                                Dinc, Nsubs, Ainc, Winc, Many, 
     &                                fslope, mangsn
      IF (Parm.GE.nset) GOTO 50
      IF (Iopt.EQ.16 .AND. Nsubs.EQ.0) skpflg = .TRUE.
      IF (Nsta.EQ.nxpos) skpflg = .FALSE.
      IF (Iopt.EQ.7 .OR. Iopt.EQ.15 .OR. Iopt.EQ.5 .OR. Iopt.EQ.16 .OR. 
     &    Iopt.EQ.17) THEN
        IF (kk.EQ.0) THEN
          IF (Ndsd.EQ.0) idck = .TRUE.
          IF (idck) idref = idref + Ndsd
        ELSEIF (skpflg) THEN
          IF (idck) idref = idref + Ndsd
        ENDIF
        IF (Nsta.EQ.nxpos .AND. idck) Ndsd = 0
        kk = kk + 1
      ENDIF
      IF (skpflg) THEN
C SKIP THROUGH COMMENT AND COORDINATE DATA RECORDS
        DO 200 i = 1, Ncom
          READ (Idev,9170)
  200   CONTINUE
        IF (Nsubs.NE.0) READ (Idev,9010)
        n = Many + 1
        DO 210 i = 1, n
          READ (Idev,deffmt,END=290)
  210   CONTINUE
        GOTO 190
      ENDIF
      subs = .TRUE.
      DO 220 i = 1, Npar
        IF (Nsta.EQ.Nxsec(i)) THEN
          Zmin = Tmin(i)
          Zmax = Tmax(i)
          Deltaz = Tinc(i)
          Deg = Ddeg(i)
          Ndsd = Kdsd(i)
          Mn1 = Kmn1(i)
          Mn2 = Kmn2(i)
          Dacorr = Datm(i)
          Zinc = Tzinc(i)
          Dinc = Tdinc(i)
          Ainc = Tainc(i)
          Winc = Twinc(i)
          fslope = Tslope(i)
          mangsn = Tmansn(i)
          GOTO 230
        ENDIF
  220 CONTINUE
  230 Zmin = Zmin + Daref
      Zmax = Zmax + Daref
      IF (Iopt.EQ.15) THEN
        IF (Parm.EQ.0) THEN
          savdlt = Deltaz
          savmin = Zmin
          Savmax = Zmax
          ipnt = l
        ELSE
          Deltaz = savdlt
        ENDIF
      ENDIF
      IF (Deltaz.EQ.0.0) Deltaz = 1.0
      dz = Deltaz*0.10 + 0.00001
      delta = Deltaz
      deltai = 1.0/delta
      IF (Iopt.EQ.15) THEN
        ktxs = ktxs + 1
        IF (Zmin.GT.savmin) THEN
          l = ipnt + (Zmin-savmin)*deltai
          savmin = Zmin
          ipnt = l
        ELSE
          Zmin = savmin
          l = ipnt
        ENDIF
        IF (Zmax.GT.Savmax) Zmax = Savmax
      ENDIF
      IF (Parm.EQ.0) THEN
        bass = Zmax
        Amaxp = Zmax - Slow
      ENDIF
C
C WRITE OUT CROSS SECTION NUMBER AND READ AND WRITE OUT COMMENTS
      IF (.NOT.((Iopt.EQ.7 .AND. Iflag.NE.1) .OR. Iopt.EQ.5 .OR. 
     &    Iopt.EQ.17)) THEN
        IF (Parm.EQ.0 .OR. Iopt.LT.6 .OR. Iopt.EQ.16) WRITE (Iprt,9155)
        WRITE (Iprt,9020) Nsta
        IF (Dacorr.NE.0.0) WRITE (Iprt,9025) Dacorr, Dtmnam
      ENDIF
      Parm = Parm + 1
      DO 240 i = 1, Ncom
        READ (Idev,9170) ident(i)
        IF (((Iopt.EQ.7 .AND. Iflag.EQ.1) .OR. (Iopt.NE.5 .AND. Iopt.NE.
     &      7)) .AND. i.LT.6) WRITE (Iprt,'(1X,A80)') ident(i)
  240 CONTINUE
      IF (Iopt.EQ.16) CALL WRDATM(1)
      IF (Nsubs.NE.0) THEN
        READ (Idev,9080) card
        READ (card,9005) sub1
        IF (sub1.EQ.blank8) THEN
          ierr = 2
          GOTO 520
        ENDIF
        READ (card,9010) (Subd(i),i=1,MXSUBS), (Subman(i),i=1,MXSUB1)
        DO 250 i = 1, Nsubs + 1
          IF (Subman(i).LE.0.0) Subman(i) = mangsn
  250   CONTINUE
      ENDIF
      IF (Zmin.GT.Zmax) THEN
        ierr = 3
        GOTO 520
      ENDIF
C
C READ COORDINATE DATA AND APPLY FLOW CORRECTION IF NECESSARY
      dc = Dacorr + Daref
      DO 260 i = 1, Many
        READ (Idev,deffmt,END=290) Y(i), zi
        Z(i) = zi + dc
  260 CONTINUE
      READ (Idev,deffmt,END=290)
      IF (mnsflg .AND. Mnpr(1,ktrec).EQ.0 .AND. Mnpr(2,ktrec).EQ.0)
     &    GOTO 180
      IF (Deg.LT.0.0) THEN
        ierr = 5
        GOTO 520
      ELSEIF (Deg.GT.89.99) THEN
        ierr = 12
        GOTO 520
      ELSEIF (Deg.NE.0.0) THEN
        dmy = COS((Deg*6.2832)/360.0)
        DO 270 i = 1, Many
          Y(i) = Y(i)*dmy
  270   CONTINUE
        DO 280 i = 1, Nsubs
          Subd(i) = Subd(i)*dmy
  280   CONTINUE
        IF (Iflag.NE.1) WRITE (Iprt,9055) IFIX(Deg)
      ENDIF
      IF (Iopt.EQ.16) CALL SUBDIV(Z,Zmax,Nsubs,delta,Nsta,Ndsd,altpch,
     &                            Zzmin,fslope,*300,*180)
      GOTO 300
  290 ierr = 4
      GOTO 520
  300 IF (Iopt.EQ.5 .OR. Iopt.EQ.7 .OR. Iopt.EQ.15 .OR. Iopt.EQ.16 .OR. 
     &    Iopt.EQ.17) THEN
        IF (Parm.EQ.1) THEN
          iold = Ndsd
          ione = Ndsd
          IF (.NOT.(idck .AND. Ndsd.GT.0)) THEN
            IF (Ndsd.EQ.0) THEN
              note = .TRUE.
              Idsd = 0
              IF (idck) Idsd = idref
            ELSEIF (Ndsd.LT.0) THEN
              CALL ERRPRT(20)
              GOTO 80
            ENDIF
          ENDIF
        ELSEIF (Ndsd.LE.0) THEN
          CALL ERRPRT(24)
          GOTO 80
        ELSEIF (note) THEN
          Diff = Ndsd
          Idsd = Idsd + Ndsd
        ELSE
          Diff = Ndsd - iold
          IF (Diff.EQ.0.0) THEN
            CALL ERRPRT(24)
            GOTO 80
          ENDIF
          iold = Ndsd
          Idsd = Ndsd - ione
        ENDIF
      ENDIF
C
C CALCULATE HEIGHT OF DATUM POINT ABOVE STREAMBED
      CALL CMINMX(Z,Many,Zzmin,Zzmax)
      prtfg = Iopt.NE.16 .AND. Iopt.NE.5
      IF (Iopt.EQ.7 .AND. Iflag.NE.1) prtfg = .FALSE.
      IF (Zzmax.LT.Zmax) Zzmax = Zmax
      IF (Iopt.EQ.7) Zmax = bass
      IF (Iopt.NE.4 .AND. Iopt.NE.7 .AND. Iopt.NE.14) THEN
        CALL MINSTG(Z,Many,Zzmin,Zmin,Zmax,delta,Iopt,l,j,*80)
C
        IF (j.NE.0) THEN
          IF (prtfg) THEN
            IF (j.EQ.1) THEN
              WRITE (Iprt,9065)
            ELSEIF (j.EQ.2) THEN
              WRITE (Iprt,9070)
            ELSEIF (j.EQ.3) THEN
              WRITE (Iprt,9075)
            ENDIF
            WRITE (Iprt,9060) Zmin
          ENDIF
          IF (Zmin.GT.savmin) THEN
            savmin = Zmin
            ipnt = l
          ENDIF
        ENDIF
      ENDIF
C
C NORMALIZE HEIGHT OF DATUM POINT ABOVE ZERO
      IF (Iopt.EQ.14) Zzmin = Slow
      DO 310 k = 1, Many
        H(k) = Z(k) - Zzmin
  310 CONTINUE
      Zmin = Zmin - Zzmin
      Zmax = Zmax - Zzmin
C
C NORMALIZE DISTANCES FROM LEFT REFERENCE POINT TO ZERO BASE
      IF (Iopt.NE.14 .AND. Iopt.NE.4) THEN
        ymin = Y(1)
        IF (Y(1).LT.Y(Many) .AND. Y(1).NE.0.0) THEN
          DO 320 k = 1, Many
            Y(k) = Y(k) - ymin
  320     CONTINUE
        ELSEIF (Y(1).GT.Y(Many)) THEN
          DO 330 k = 1, Many
            Y(k) = 0.0 - (Y(k)-ymin)
  330     CONTINUE
        ENDIF
      ENDIF
      CALL XTRPBN(Zmax,Zzmin,Iopt,prtfg,izflg,izzflg,*80)
      zstage = Zmax + Zzmin
      IF (Iopt.EQ.15 .AND. izzflg.NE.0) iak = .TRUE.
      IF (Zmax.LT.Savmax) Savmax = zstage
      IF (Iflag.EQ.1) THEN
        WRITE (Iprt,9005)
        CALL PERPLT(*180,*80)
      ENDIF
  340 IF (Iopt.NE.16 .OR. Iopt.NE.7) WRITE (Iprt,9005)
C
C     Perform output function based on IOPT
C
      IF (Iopt.EQ.4) THEN
C
C PLOT CROSS SECTIONS ON LINE PRINTER (OUTPUT OPTION 4)
        Hmax = H(1)
        yerr = .FALSE.
        xerr = .FALSE.
        IF (H(Many).GT.H(1)) Hmax = H(Many)
        IF (Zinc.NE.0.00) THEN
          yscale = Zinc*0.2
          IF (ABS(yscale)*50.LT.IFIX(Hmax+0.5)) yerr = .TRUE.
        ELSE
          dmy = 0.0
          CALL SCALER(yscale,Hmax,dmy,50,2)
        ENDIF
        IF (Dinc.LT.0.0) THEN
          CALL ERRPRT(26)
          GOTO 80
        ELSEIF (Dinc.GT.0.00) THEN
          IF (Dinc*12.LT.IFIX(Y(Many)-Y(1)+0.5)) xerr = .TRUE.
          xscale = Dinc*0.1
        ELSE
          CALL SCALER(xscale,Y(Many),Y(1),120,-1)
        ENDIF
        DO 350 i = 1, Many
          iy(i) = IFIX(Y(i)+0.5)
  350   CONTINUE
        CALL PLOTER(1,H,yscale,iy,xscale,Many,Zzmin,yerr,xerr,prtflg)
      ELSEIF (Iopt.EQ.7) THEN
        CALL PERPLT(*180,*80)
      ELSEIF (Iopt.EQ.16) THEN
        CALL SUBDIV(Z,Zmax,Nsubs,delta,Nsta,Ndsd,altpch,Zzmin,fslope,
     &              *300,*180)
      ELSEIF (Iopt.EQ.14) THEN
C PLOT CROSS SECTIONS ON CALCOMP PLOTTER (OUTPUT OPTION 14)
        IF (Dinc.LT.0.0) THEN
          CALL ERRPRT(26)
          GOTO 80
        ENDIF
        CALL XSPLOT
      ELSE
C
C output options 1,2,3,5,6,8,11,12,13, 15, or 17
C
C PRINT TABLE (OUTPUT OPTION 5)
        Jflag = 0
        IF (Iopt.EQ.5) THEN
          nn = MXCOMP
          CALL MOVEI0(ialt,nn)
          CALL MOVEI0(iwlt,nn)
          CALL MOVEI0(iart,nn)
          CALL MOVEI0(iwrt,nn)
          CALL MOVEI0(iwplt,nn)
          CALL MOVEI0(iwprt,nn)
C WRITE OUT HEADERS
          IF (Diff.EQ.0.0 .AND. Parm.NE.1) WRITE (Iprt,9160)
          IF (Diff.EQ.0.0 .OR. Parm.EQ.1) dflg = .TRUE.
          IF (.NOT.dflg) THEN
            WRITE (Iprt,9085) jsta, Nsta
            CALL WRDATM(1)
            WRITE (Iprt,9095)
          ENDIF
        ENDIF
C
C CALCULATE WIDTH, WETTED PERIMETER, AND AREA
  360   CALL CALAWP
        Stage(l) = S + Zzmin
C
C COMBINE AREA OF MAIN CHANNEL AND AREA OF SUBCHANNELS
        Xarea(l) = Area + Altc + Artc
        Iarea(l) = IFIX(Xarea(l)+0.5)
        Xwide(l) = Width + Ym - Yl + Wltc + Wrtc
        Iwide(l) = IFIX(Xwide(l)+0.5)
        Rwetp(l) = Wetp + Wpltc + Wprtc
        Iwetp(l) = IFIX(Rwetp(l)+0.5)
        IF (Iopt.EQ.8 .OR. Iopt.EQ.17 .OR. Iopt.EQ.5 .OR. Iopt.EQ.6)
     &      THEN
C
C CALCULATE HYDRAULIC RADIUS
          Xhrad(l) = 0.0
          IF (Wetp.NE.0.0) Xhrad(l) = Xarea(l)/Rwetp(l)
          IF (Iopt.EQ.5) THEN
            IF (Wltc.EQ.0.0 .AND. Wrtc.EQ.0.0) GOTO 370
            IF (Wltc.NE.0.0) THEN
              ialt(l) = IFIX(Altc+0.5)
              iwlt(l) = IFIX(Wltc+0.5)
              iwplt(l) = IFIX(Wpltc+0.5)
            ENDIF
            IF (Wrtc.NE.0.0) THEN
              iart(l) = IFIX(Artc+0.5)
              iwrt(l) = IFIX(Wrtc+0.5)
              iwprt(l) = IFIX(Wprtc+0.5)
            ENDIF
          ENDIF
        ELSEIF (Iopt.EQ.15) THEN
          IF (iak .AND. zstage.LT.stemp) stemp = zstage
          Larea(l,ktxs) = Iarea(l)
CC          LWIDTH(L,KTXS)=Iwide(l)
          ldist(ktxs) = Ndsd
          IF (idck) ldist(ktxs) = Idsd
        ENDIF
        IF (Iopt.NE.5) GOTO 390
  370   avedep(l) = Xarea(l)/Xwide(l)
        ymide(l) = Ymid
        IF (.NOT.dflg) THEN
          DO 380 i = 1, lastl
            IF (ABS(stagj(i)-Stage(l)).LT.dz) THEN
C
C CALCULATE RATES OF CHANGE
              xp = 1.0/Diff
              yp = (Iwetp(l)-jwetp(i))*xp
              dc = (Iwide(l)-jwide(i))*xp
              d1 = (Iarea(l)-jarea(i))*xp
              d2 = (Xhrad(l)-yhrad(i))*xp
              d3 = (avedep(l)-avdep(i))*xp
              WRITE (Iprt,9105) Stage(l), d1, dc, yp, d2, d3
              GOTO 390
            ENDIF
  380     CONTINUE
          WRITE (Iprt,9115) Stage(l)
        ENDIF
  390   S = S + delta
        IF (S.LE.Zmax) THEN
          l = l + 1
          Jflag = 1
          IF (l.GT.MXCOMP) THEN
            CALL ERRPRT(30)
            GOTO 80
          ENDIF
          GOTO 360
        ENDIF
        IF (Iopt.EQ.15) THEN
          IF (ktxs.EQ.nset) GOTO 50
        ELSEIF (Iopt.EQ.5) THEN
C SAVE COMPUTATIONS AT PREVIOUS CROSS SECTION
          lastl = l
          jsta = Nsta
          WRITE (Iprt,9155)
          WRITE (Iprt,9020) Nsta
          IF (Dacorr.NE.0.0) WRITE (Iprt,9025) Dacorr, Dtmnam
          DO 400 i = 1, Ncom
            WRITE (Iprt,'(1X,A80)') ident(i)
  400     CONTINUE
          CALL WRDATM(1)
          WRITE (Iprt,9035) Zzmin
          IF (j.EQ.1) WRITE (Iprt,9065)
          IF (j.EQ.2) WRITE (Iprt,9070)
          IF (j.EQ.3) WRITE (Iprt,9075)
          IF (j.EQ.1 .OR. j.EQ.2 .OR. j.EQ.3) 
     &        WRITE (Iprt,9060) Zmin + Zzmin
          IF (MOD(izflg,2).EQ.1) WRITE (Iprt,9050) ' LEFT'
          IF (MOD(izzflg,2).EQ.1) WRITE (Iprt,9045) ' LEFT', zstage
          IF (izflg.GT.1) WRITE (Iprt,9050) 'RIGHT'
          IF (izzflg.GT.1) WRITE (Iprt,9045) 'RIGHT', Z(Many-1) + Zzmin
          WRITE (Iprt,9090)
          DO 410 i = 1, l
            kk = Iwetp(i) - iwplt(i) - iwprt(i)
            d2 = Xhrad(i)/avedep(i)
            d3 = (Yzmax-ymide(i))*2.0*(Stage(i)-Zzmin-avedep(i))
     &           /Xarea(i)
            WRITE (Iprt,9100) Stage(i), Iarea(i) - ialt(i) - iart(i), 
     &                        Iwide(i) - iwlt(i) - iwrt(i), kk, Xhrad(i)
     &                        , avedep(i), d2, d3
            IF (iwlt(i).NE.0) WRITE (Iprt,9110) ialt(i), iwlt(i), 
     &                               iwplt(i)
            IF (iwrt(i).NE.0) WRITE (Iprt,9120) iart(i), iwrt(i), 
     &                               iwprt(i)
            jwide(i) = Iwide(i)
            stagj(i) = Stage(i)
            jarea(i) = Iarea(i)
            jwetp(i) = Iwetp(i)
            avdep(i) = avedep(i)
            yhrad(i) = Xhrad(i)
  410     CONTINUE
C
        ELSEIF (Iopt.GT.10 .AND. Iopt.LT.14) THEN
C
C PLOT STAGE CURVES ON DIGITAL PLOTTER (OUTPUT OPTIONS 11, 12, AND 13)
          CALL STGPLT(l,Stage,Xarea,Xwide)
        ELSEIF (Iopt.LT.4) THEN
C
C PLOT STAGE CURVES ON LINE PRINTER (OUTPUT OPTIONS 1, 2, AND 3)
          IF (Zinc.NE.0.00) THEN
            yscale = ABS(Zinc)*0.2
            IF (ABS(yscale)*50.LT.IFIX(Stage(l)+0.5)) yerr = .TRUE.
          ELSE
            CALL SCALER(yscale,Stage(l),Stage(1),50,2)
          ENDIF
          IF (Iopt.NE.2) THEN
            amin = Iarea(1)
            amax = Iarea(l)
            IF (Ainc.NE.0.0) THEN
              Ainc = ABS(Ainc)
              IF (Ainc*12.LT.IFIX(Iarea(Many)-Iarea(1)+0.5))
     &            xerr = .TRUE.
              xscale = Ainc*0.1
            ELSE
              CALL SCALER(xscale,amax,amin,120,0)
            ENDIF
            CALL PLOTER(2,Stage,yscale,Iarea,xscale,l,Zzmin,yerr,xerr,
     &                  prtflg)
            IF (Iopt.NE.3) GOTO 180
            WRITE (Iprt,9155)
            WRITE (Iprt,9020) Nsta
          ENDIF
          IF (Winc.NE.0.0) THEN
            Winc = ABS(Winc)
            IF (Winc*12.LT.IFIX(Iwide(Many)-Iwide(1)+0.5)) xerr = .TRUE.
            xscale = Winc*0.1
          ELSE
            dmy = Iwide(1)
            CALL SCALER(xscale,FLOAT(Iwide(l)),dmy,120,0)
          ENDIF
          CALL PLOTER(3,Stage,yscale,Iwide,xscale,l,Zzmin,yerr,xerr,
     &                prtflg)
        ELSEIF (Iopt.EQ.6 .OR. Iopt.EQ.8 .OR. Iopt.EQ.17) THEN
C
          IF (mnsflg) THEN
C
C COMPUTE MEANS FOR OUTPUT OPTIONS 6, 8, AND 17
            kk = 1
  420       mean = Mnpr(kk,ktrec)
            IF (Iopt.EQ.17) THEN
              Lenflw(mean) = Lenflw(mean) + Ndsd
              Slopes(mean) = Slopes(mean) + fslope
            ENDIF
            j = 0
            IF (mean.NE.0) THEN
              szmin = Zmn(mean)
              szmax = Stage(l)
              IF (szmax.LE.szmin) THEN
                CALL ERRPRT(19)
                GOTO 80
              ENDIF
              IF (Stage(1).GT.szmin) THEN
                stage1 = Stage(1)
                DO 430 i = 1, MXTBLE
                  stage1 = stage1 - delta
                  IF (stage1.LE.szmin) THEN
                    IF (stage1.LT.szmin) THEN
                      j = i - 1
                      stage1 = stage1 + delta
                    ELSE
                      j = i
                    ENDIF
                    mark = 1 - j
                    GOTO 450
                  ENDIF
  430           CONTINUE
                GOTO 490
              ELSE
                DO 440 i = 1, l
                  IF (Stage(i).GE.szmin) THEN
                    mark = i
                    stage1 = Stage(mark)
                    GOTO 450
                  ENDIF
  440           CONTINUE
              ENDIF
              GOTO 500
  450         IF (Mnct(mean).LT.1) THEN
                dc = AMOD(szmin,delta)
                stg1 = szmin + delta - dc
                IF (dc.EQ.0.0 .OR. szmin.LE.0.0) stg1 = stg1 - delta
                Nstor(mean) = IFIX((szmax-stg1)*deltai) + 1
                IF (Nstor(mean).GT.MXTBLE) Nstor(mean) = MXTBLE
              ENDIF
              n = Nstor(mean)
              IF (Mnct(mean).LT.1) THEN
                yp = stg1
                DO 460 i = 1, n
                  Zstg(i,mean) = yp
                  yp = yp + delta
  460           CONTINUE
              ENDIF
C
C SUM AREAS AND WIDTHS OR WETTED PERIMETERS AND HYDRAULIC RADII AND
C INTERPOLATE IF NECESSARY
              dc = stg1 - stage1
              DO 480 i = 1, n
                IF (i.GT.j) THEN
                  k = mark + i - 1
                  IF (dc.LT.0) THEN
                    k = k - 1
                    IF (k.EQ.0) k = 1
                  ELSEIF (dc.EQ.0) THEN
                    IF (k.GT.l) GOTO 490
                    ara = Xarea(k)
                    wid = Xwide(k)
                    hyrad = Xhrad(k)
                    wtp = Rwetp(k)
                    GOTO 470
                  ENDIF
                  IF (k+1.GT.l) GOTO 490
                  sara = (Xarea(k+1)-Xarea(k))*deltai
                  ara = Xarea(k) - sara*Stage(k)
                  ara = Zstg(i,mean)*sara + ara
                  swid = (Xwide(k+1)-Xwide(k))*deltai
                  wid = Xwide(k) - swid*Stage(k)
                  wid = Zstg(i,mean)*swid + wid
                  swtp = (Rwetp(k+1)-Rwetp(k))*deltai
                  wtp = Rwetp(k) - swtp*Stage(k)
                  wtp = Zstg(i,mean)*swtp + wtp
                  shyrad = (Xhrad(k+1)-Xhrad(k))*deltai
                  hyrad = Xhrad(k) - shyrad*Stage(k)
                  hyrad = Zstg(i,mean)*shyrad + hyrad
  470             IF (Iopt.EQ.17) THEN
C                   Compute discharge based on Manning's equation
                    qq = (1.486/mangsn)*ara
                    qq = qq*hyrad**0.66667*SQRT(fslope)
                    Qsum(i,mean) = Qsum(i,mean) + qq
                  ENDIF
                  Isum(i,mean) = Isum(i,mean) + 1
                  Arsum(i,mean) = Arsum(i,mean) + ara
                  Wdsum(i,mean) = Wdsum(i,mean) + wid
                  Wpsum(i,mean) = Wpsum(i,mean) + wtp
                  Hrsum(i,mean) = Hrsum(i,mean) + hyrad
                ENDIF
  480         CONTINUE
  490         Mnct(mean) = Mnct(mean) + 1
  500         IF (kk.NE.2) THEN
                kk = 2
                GOTO 420
              ENDIF
            ENDIF
C
          ELSEIF (Iopt.EQ.8) THEN
C        PUNCH WETTED PERIMETER AND HYDRAULIC RADIUS RECORDS
            IF (Stage(l).GT.999.9 .OR. Stage(1).LT.-99.9) THEN
              WRITE (Ipun,9135) l, (Stage(i),Iwetp(i),i=1,l)
              WRITE (Ipun,9150) l, (Stage(i),Xhrad(i),i=1,l)
            ELSEIF (Stage(l).GT.99.99 .OR. Stage(1).LT.-9.99) THEN
              WRITE (Ipun,9130) l, (Stage(i),Iwetp(i),i=1,l)
              WRITE (Ipun,9145) l, (Stage(i),Xhrad(i),i=1,l)
            ELSE
              WRITE (Ipun,9125) l, (Stage(i),Iwetp(i),i=1,l)
              WRITE (Ipun,9140) l, (Stage(i),Xhrad(i),i=1,l)
            ENDIF
C
C        PUNCH AREA AND WIDTH RECORDS (Iopt.eq.6)
          ELSEIF (Stage(l).GT.999.9 .OR. Stage(1).LT.-99.9) THEN
            WRITE (Ipun,9135) l, (Stage(i),Iarea(i),i=1,l)
            WRITE (Ipun,9135) l, (Stage(i),Iwide(i),i=1,l)
          ELSEIF (Stage(l).GT.99.99 .OR. Stage(1).LT.-9.99) THEN
            WRITE (Ipun,9130) l, (Stage(i),Iarea(i),i=1,l)
            WRITE (Ipun,9130) l, (Stage(i),Iwide(i),i=1,l)
          ELSE
            WRITE (Ipun,9125) l, (Stage(i),Iarea(i),i=1,l)
            WRITE (Ipun,9125) l, (Stage(i),Iwide(i),i=1,l)
          ENDIF
C
        ENDIF
      ENDIF
      GOTO 180
C
C TERMINATE MAIN PROGRAM
  510 ierr = 11
  520 CALL ERRPRT(ierr)
  530 IF (Pflag) CALL PLOT(3.0,0.0,999)
      IF (.NOT.opt16) CLOSE (Sbdunt,STATUS='DELETE')
      IF (.NOT.Pflag) CLOSE (Pltunt,STATUS='DELETE')
      IF (.NOT.opt9) CLOSE (Stndrd,STATUS='DELETE')
      IF (.NOT.opt68) CLOSE (Ipun,STATUS='DELETE')
      STOP
C
 9005 FORMAT (2X,A8)
 9010 FORMAT (2X,6F8.2,7F8.4)
 9015 FORMAT (I2,2X,I1,3F7.2,F3.0,I6,1X,2I2,F8.2,2(1X,F6.1),1X,I1,2F6.1,
     &        I4,F6.4,F6.3)
 9020 FORMAT ('+',56X,'CROSS SECTION NUMBER',I3,/)
 9025 FORMAT (' A USER INPUT DATUM CORRECTION OF',F8.2,
     &        ' HAS BEEN APPLIED TO ADJUST THE ELEVATIONS TO ',A20)
 9030 FORMAT (' CHANNEL GEOMETRY ANALYSIS PROGRAM (CGAP) ',A,/,
     &' DOCUMENTATION:  USGS WRI 85-4335  "A COMPUTER PROGRAM FOR ANALYZ
     &ING CHANNEL GEOMETRY"')
 9035 FORMAT (' THALWEG ELEVATION =',F8.2,' FEET')
 9040 FORMAT (//
     &' PROCESSING OF THE ABOVE CROSS SECTIONS AS DEFINED BY OUTPUT OPTI
     &ON ',I2,' IS COMPLETE.')
 9045 FORMAT (' EXTRAPOLATION OF THE ',A5,
     &        ' BANK CONTOUR TO MAXIMUM STAGE IS NOT POSSIBLE.',/,
     &        ' MAXIMUM STAGE IS REDUCED TO ',F7.2,' FEET.')
 9050 FORMAT (' THE ',A5,' BANK HAS BEEN EXTRAPOLATED.')
 9055 FORMAT (
     &' THE LONGITUDINAL WIDTH OF THIS CROSS SECTION HAS BEEN ADJUSTED T
     &O COMPENSATE FOR A(N) ',I2,' DEGREE SKEW FROM THALWEG OF FLOW.')
 9060 FORMAT ('+',T30,
     &' MINIMUM STAGE; THE MINIMUM STAGE SPECIFIED FOR COMPUTATION WAS C
     &HANGED TO ',F7.2,'.')
 9065 FORMAT (' NO STAGE READINGS BELOW THE')
 9070 FORMAT (' ONLY ONE STAGE READING BELOW')
 9075 FORMAT (' TWO CHANNELS OF FLOW AT THE')
 9080 FORMAT (A112)
 9085 FORMAT ('1',15X,'RATE OF CHANGE IN THE FOLLOWING STAGE RELATED',/,
     &        17X,'PARAMETERS BETWEEN CROSS SECTIONS',I3,' AND',I3,/)
 9090 FORMAT ('   STAGE',4X,'(LEFT   AREA  (RIGHT',9X,'WIDTH',13X,
     &        'WETTED',8X,'HYDRAULIC  AVERAGE    RATIO OF    ASYMMETRY',
     &        /,' ',T11,'CHANNELS)',T26,'CHANNELS)',T59,'PERIMETER',T76,
     &        'RADIUS',4X,'DEPTH',3X,'RADIUS/DEPTH  ON THALWEG')
 9095 FORMAT (/,3X,'STAGE',8X,'AREA',7X,
     &        'WIDTH      WETTED      HYDRAULIC    AVERAGE',/,37X,
     &        'PERIMETER     RADIUS       DEPTH')
 9100 FORMAT (F9.2,10X,I6,16X,I5,14X,I5,5X,2F10.2,F11.2,F13.2)
 9105 FORMAT (2X,F7.2,5(F12.3))
 9110 FORMAT ('+',T13,'(',I5,')',T36,'(',I4,')',T55,'(',I4,')')
 9115 FORMAT (2X,F7.2,5(9X,'-- '))
 9120 FORMAT ('+',T26,'(',I5,')',T47,'(',I4,')',T66,'(',I4,')')
 9125 FORMAT (I2/(5(F5.2,I8,2X)))
 9130 FORMAT (I2/(5(F5.1,I8,2X)))
 9135 FORMAT (I2/(5(F5.0,I8,2X)))
 9140 FORMAT (I2/(5(F5.2,F8.2,2X)))
 9145 FORMAT (I2/(5(F5.1,F8.2,2X)))
 9150 FORMAT (I2/(5(F5.0,F8.2,2X)))
 9155 FORMAT ('1')
 9160 FORMAT (
     &' SUBREACH LENGTH UNDEFINED; COMPUTATION OF RATES OF CHANGE SUPPRE
     &SSED',///)
 9165 FORMAT (2X,2I2,F3.0,3X,I3,2X,I1,F8.2,3I2,A20,I1,F5.3)
 9170 FORMAT (A80)
 9175 FORMAT (
     &' DATA IS STORED ON DISK AS SEQUENTIAL DATA SET AS REQUESTED BY OU
     &TPUT OPTION 9.')
      END
