#!/bin/sh
# usr/opt/wrdapp/cgap/test/test.sh -- run cgap test data sets
#
# Usage: test.sh [start [stop]]
#        test.sh [start [stop] | tee test.out
#
#        where: start = starting test number
#                stop = ending test number (may be same as start)
#
# To use this script for another program in a different directory, globally
# change the program name (be sure to change both upper and lower case
# occurrences) and set the default value for the Stop variable as appropriate.
#
# History: 12/24/91, mblalock, initial coding
#          04/27/92, mygoze, restructuring
#          02/01/93, rsregan, modified for use with CGAP
#
# Variable definitions
# --------------------
#
  TOPDIR=..
  DATA=$TOPDIR/data
  CGAP=$TOPDIR/bin/cgap
  CHECK=$TOPDIR/test/check.sh
  CLEAN=$TOPDIR/test/clean.sh
  DIVD=========================================
#
#
  exec 2>&1                                # stderr shows up in .out file

  Start=${1:-1}                            # by default, start at 1
  Stop=${2:-4}                             # by default, stop at 4
  if [ $Start -lt 1 ] ; then Start=1 ; fi
  if [ $Stop -lt 1 ] ; then Stop=4 ; fi
  if [ $Start -gt 4 -o $Stop -gt 4 ]
  then
    echo
    echo "Warning, invalid arguments--test range is 1 - 4 for CGAP"
    echo "input arguments were $Start - $Stop"
    echo
    if [ $Stop -gt 4 ] ; then Stop=4 ; fi
    if [ $Start -gt 4 ]
    then
      echo "no CGAP tests will be performed"
    else
      echo "Tests $Start - $Stop will be performed"
    fi
    echo
  fi

#
# begin test runs
#
  Test=$Start
  $CLEAN

  if [ $Test -ge $Start -a $Test -le $Stop ]
  then
    echo
    echo $DIVD$DIVD
    echo "Begin processing one-d CGAP test runs $Start to $Stop"
    echo
    date
  fi

  while [ $Test -ge $Start -a $Test -le $Stop ]
  do
    echo
    echo
    echo $DIVD$DIVD
    echo "Test run number $Test"
    PROG=$CGAP
    GO=$DATA/go
    Name=cgap$Test
    if [ $Test -eq 1 ]
      then
        echo "cgap1.plt contains graphics in postscript format"
        cp $DATA/gkcgap1.cfg DIGSPLT1.CFG
        chmod 644 DIGSPLT1.CFG
        GO=$DATA/ctst1.go
      fi
    if [ $Test -eq 2 ]
      then
        echo "cgap2.plt contains graphics in postscript format"
        cp $DATA/gkcgap2.cfg DIGSPLT1.CFG
        chmod 644 DIGSPLT1.CFG
      fi

    echo

    rm -f CGAP.MTR
    if [ $Test -ne 1 ] ; then 
	cp $DATA/$Name.MTR CGAP.MTR ; 
	chmod 644 CGAP.MTR ; fi
    $PROG < $GO > $Name.log
    rm CGAP.MTR
    Test=`expr $Test + 1`
  done
#
  if [ -f gkcgap.cfg ] ; then rm gkcgap.cfg ; fi
  if [ $Test -ge $Start -a $Test -le $Stop ]
  then
    echo
    echo
    echo $DIVD$DIVD
    echo "Completed one-d CGAP test runs $Start to $Stop"
    echo
  fi

# check output against original output in data subdirectory
  $CHECK cgap
